=================
seman
=================

Semantics tools.

.. image:: https://badge.fury.io/py/seman.svg
    :target: https://badge.fury.io/py/seman

.. image:: https://img.shields.io/pypi/dw/seman?style=flat
    :target: https://pypistats.org/packages/seman

.. image:: https://github.com/kannkyo/seman/actions/workflows/python-ci.yml/badge.svg
    :target: https://github.com/kannkyo/seman/actions/workflows/python-ci.yml

.. image:: https://github.com/kannkyo/seman/actions/workflows/scorecards.yml/badge.svg
    :target: https://github.com/kannkyo/seman/actions/workflows/scorecards.yml
